# PyBugReporter
A python library for catching thrown exceptions and automatically creating issues on a GitHub repo.

Not recommended for public repos, as a malicious user could spam your issues with fake exceptions.
